<?php
	
	namespace Tmont\Midi\Tests\Util;

	use PHPUnit_Framework_TestCase;
	use Tmont\Midi\Util\Instrument;

	class InstrumentTest extends PHPUnit_Framework_TestCase {
		
		public function testGetInstrumentNameThrowsInvalidArgumentException() {
			$this->setExpectedException('InvalidArgumentException');
			Instrument::getInstrumentName(-1);
		}
		
		public function testGetInstrumentName() {
			$instrumentMap = array(
				Instrument::ConcertGrand              => 'Concert Grand',
				Instrument::Piano                     => 'Piano',
				Instrument::ElectricPiano             => 'Electric Piano',
				Instrument::HonkyTonk                 => 'Honky Tonk',
				Instrument::FenderRhodesElectricPiano => 'Fender Rhodes Electric Piano',
				Instrument::PianoWithChorus           => 'Piano with Chorus',
				Instrument::Harpsichord               => 'Harpsichord',
				Instrument::HohnerClavinetD6          => 'Hohner Clavinet D6',
				Instrument::Celesta                   => 'Celesta',
				Instrument::Glockenspiel              => 'Glockenspiel',
				Instrument::MusicBox                  => 'Music Box',
				Instrument::Vibraphone                => 'Vibraphone',
				Instrument::Marimba                   => 'Marimba',
				Instrument::Xylophone                 => 'Xylophone',
				Instrument::TubularBells              => 'Tubular Bells',
				Instrument::Dulcimer                  => 'Dulcimer',
				Instrument::HammondOrgan              => 'Hammond Organ',
				Instrument::PercussiveOrgan           => 'Percussive Organ',
				Instrument::RockOrgan                 => 'Rock Organ',
				Instrument::ChurchOrgan               => 'Church Organ',
				Instrument::ReedOrgan                 => 'Reed Organ',
				Instrument::Accordion                 => 'Accordion',
				Instrument::Harmonica                 => 'Harmonica',
				Instrument::TangoAccordion            => 'Tango Accordion',
				Instrument::AcousticGuitarNylon       => 'Acoustic Guitar (nylon)',
				Instrument::AcousticGuitarSteel       => 'Acoustic Guitar (steel)',
				Instrument::ElectricGuitarJazz        => 'Electric Guitar (jazz)',
				Instrument::ElectricGuitarClean       => 'Electric Guitar (clean)',
				Instrument::ElectricGuitarMuted       => 'Electric Guitar (muted)',
				Instrument::ElectricGuitarOverdriven  => 'Electric Guitar (overdriven)',
				Instrument::ElectricGuitarDistorted   => 'Electric Guitar (distorted)',
				Instrument::GuitarHarmonics           => 'Guitar Harmonics',
				Instrument::DoubleBassFinger          => 'Double Bass (finger)',
				Instrument::ElectricBassFinger        => 'Electric Bass (finger)',
				Instrument::ElectricBassPlectrum      => 'Electric Bass (plectrum)',
				Instrument::FretlessBass              => 'Fretless Bass',
				Instrument::SlapBass1                 => 'Slap Bass 1',
				Instrument::SlapBass2                 => 'Slap Bass 2',
				Instrument::SynthesizerBass1          => 'Synthesizer Bass 1',
				Instrument::SynthesizerBass2          => 'Synthesizer Bass 2',
				Instrument::Violin                    => 'Violin',
				Instrument::Viola                     => 'Viola',
				Instrument::Cello                     => 'Cello',
				Instrument::DoubleBassBowed           => 'Double Bass (bowed)',
				Instrument::ViolinTremolo             => 'Violin (tremolo)',
				Instrument::ViolinPizzicato           => 'Violin (pizzicato)',
				Instrument::OrchestraHarp             => 'Orchestra Harp',
				Instrument::Drum                      => 'Drum',
				Instrument::StringEnsemble1           => 'String Ensemble 1',
				Instrument::StringEnsemble2           => 'String Ensemble 2',
				Instrument::SynthesizerStrings1       => 'Synthesizer Strings 1',
				Instrument::SynthesizerStrings2       => 'Synthesizer Strings 2',
				Instrument::ChoirAahs                 => 'Choir Aahs',
				Instrument::ChoirOohs                 => 'Choir Oohs',
				Instrument::SynthesizerVoice          => 'Synthesizer Voice',
				Instrument::OrchestraComplete         => 'Orchestra Complete',
				Instrument::Trumpet                   => 'Trumpet',
				Instrument::Trombone                  => 'Trombone',
				Instrument::Tuba                      => 'Tuba',
				Instrument::MutedTrumpet              => 'Muted Trumpet',
				Instrument::Horn                      => 'Horn',
				Instrument::BrassSection              => 'Brass Section',
				Instrument::SynthesizerBrass1         => 'Synthesizer Brass 1',
				Instrument::SynthesizerBrass2         => 'Synthesizer Brass 2',
				Instrument::SopranoSaxophone          => 'Soprano Saxophone',
				Instrument::AltoSaxophone             => 'Alto Saxophone',
				Instrument::TenorSaxophone            => 'Tenor Saxophone',
				Instrument::BaritoneSaxophone         => 'Baritone Saxophone',
				Instrument::Oboe                      => 'Oboe',
				Instrument::EnglishHorn               => 'English Horn',
				Instrument::Bassoon                   => 'Bassoon',
				Instrument::Clarinet                  => 'Clarinet',
				Instrument::PiccoloFlute              => 'Piccolo Flute',
				Instrument::Flute                     => 'Flute',
				Instrument::Recorder                  => 'Recorder',
				Instrument::PanPipes                  => 'Pan Pipes',
				Instrument::BottleBlow                => 'Bottle Blow',
				Instrument::Shakuhachi                => 'Shakuhachi',
				Instrument::Whistle                   => 'Whistle',
				Instrument::Ocarina                   => 'Ocarina',
				Instrument::SquareSynth               => 'Square (synth)',
				Instrument::SawToothSynth             => 'Saw Tooth (synth)',
				Instrument::CaliopeSynth              => 'Caliope (synth)',
				Instrument::ChiffSynth                => 'Chiff (synth)',
				Instrument::CharangSynth              => 'Charang (synth)',
				Instrument::VoiceSynth                => 'Voice (synth)',
				Instrument::FifthSynth                => 'Fifth (synth)',
				Instrument::BrassLeadSynth            => 'Brass+Lead (synth)',
				Instrument::NewAgeSynthPad            => 'New Age (synth pad)',
				Instrument::WarmSynthPad              => 'Warm (synth pad)',
				Instrument::PolysynthSynthPad         => 'Polysynth (synth pad)',
				Instrument::ChoirSynthPad             => 'Choir (synth pad)',
				Instrument::BowedSynthPad             => 'Bowed (synth pad)',
				Instrument::MetallicSynthPad          => 'Metallic (synth pad)',
				Instrument::HaloSynthPad              => 'Halo (synth pad)',
				Instrument::SweepSynthPad             => 'Sweep (synth pad)',
				Instrument::RainSynthEffect           => 'Rain (synth effect)',
				Instrument::SoundtrackSynthEffect     => 'Soundtrack (synth effect)',
				Instrument::CrystalSynthEffect        => 'Crystal (synth effect)',
				Instrument::AtmosphereSynthEffect     => 'Atmosphere (synth effect)',
				Instrument::BrightnessSynthEffect     => 'Brightness (synth effect)',
				Instrument::GoblinsSynthEffect        => 'Goblins (synth effect)',
				Instrument::EchoesSynthEffect         => 'Echoes (synth effect)',
				Instrument::SciFiSynthEffect          => 'Sci Fi (synth effect)',
				Instrument::Sitar                     => 'Sitar',
				Instrument::Banjo                     => 'Banjo',
				Instrument::Shamisen                  => 'Shamisen',
				Instrument::Koto                      => 'Koto',
				Instrument::Kalimba                   => 'Kalimba',
				Instrument::Bagpipe                   => 'Bagpipe',
				Instrument::Fiddle                    => 'Fiddle',
				Instrument::Shanai                    => 'Shanai',
				Instrument::TinkleBell                => 'Tinkle Bell',
				Instrument::Agogo                     => 'Agogo',
				Instrument::SteelDrum                 => 'Steel Drum',
				Instrument::Woodblock                 => 'Woodblock',
				Instrument::Taikodrum                 => 'Taiko-drum',
				Instrument::MelodicTom                => 'Melodic Tom',
				Instrument::SynthesizedDrum           => 'Synthesized Drum',
				Instrument::CymbalHiHat               => 'Cymbal Hi-Hat',
				Instrument::GuitarFretNoise           => 'Guitar Fret Noise',
				Instrument::BreathNoise               => 'Breath Noise',
				Instrument::Seashore                  => 'Seashore',
				Instrument::BirdSong                  => 'Bird Song',
				Instrument::TelephoneRing             => 'Telephone Ring',
				Instrument::Helicopter                => 'Helicopter',
				Instrument::Applause                  => 'Applause',
				Instrument::Gunshot                   => 'Gunshot'
			);
			
			foreach ($instrumentMap as $instrument => $name) {
				$this->assertEquals(Instrument::getInstrumentName($instrument), $name);
			}
		}

	}

?>